import sys
import WebSessionsDatabase, WebSessionsConfig, WebLogs

showhelp = ('--help' in sys.argv) or ('-h' in sys.argv) or ('/?' in sys.argv) or ('/h' in sys.argv)
verbose = ('--verbose' in sys.argv)
clear_dbs = ('--clear-databases' in sys.argv)
clear_dns_cache = ('--clear-dns' in sys.argv)

if showhelp or len(sys.argv) == 1:
	print 'WebSessions Log Parser'
	print
	print 'python log-parser.py CONF_FILE [--verbose] [--clear-databases] [--clear-dns]'
	print
	print 'CONF_FILE'
	print '    The path to the configuration file to use.'
	print
	print '--verbose'
	print '    If specified, will give details of what the log parser is doing, as well as'
	print '    a listing of which line number is currently being parsed.'
	print
	print '--clear-databases'
	print '    Delete all session data from the databases specified in the configuration'
	print '    file.'
	print
	print '--clear-dns'
	print '    Clear the name resolution cache in the database.'
	sys.exit(0)

if verbose:
	print "Verbose mode"

cp = WebSessionsConfig.ConfigParser(sys.argv[1])

# Loop through blocks
for block in cp.blocks:
	if verbose: print "Parsing log files for %s" % block.name
	
	# Set the database and create a structure if it doesn't exist
	WebSessionsDatabase.set_database(block.mysql_host, block.mysql_user, block.mysql_passwd, block.mysql_dbname)

	if clear_dbs:
		if verbose: print "Clearing database"
		WebSessionsDatabase.clear_session_database()

	if clear_dns_cache:
		if verbose: print "Clearing DNS Cache"
		WebSessionsDatabase.clear_dns_database()
	
	WebSessionsDatabase.create_database_structure()
	sl = WebSessionsDatabase.SessionLogger(block)

	# Loop through filenames
	for filename in block.logfiles:
		if verbose: print "Parsing %s" % filename

		lp = WebLogs.LogParser(filename)
		for lf in block.log_formats:
			lp.add_format(WebLogs.LogFormat(lf))
		
		# Loop through log entries
		try:
			lineCount = 0
			while 1:
				lineCount += 1
				if verbose:
					print ("Parsing line %s                                                  \r" % lineCount),
				try:
					le = lp.next()
					if not sl.is_old_hit(le) and not sl.is_ignored_hit(le):
						session_id = sl.find_session_id(le)
						sl.log_hit(session_id, le)
						
				except WebLogs.InvalidLogFormatError, err:
					print
					print "Line %s of file %s: invalid log format: %s" % (lineCount, filename, err)
		except StopIteration:
			print
		
		
		lp.close()
		WebSessionsDatabase.optimize_tables()
	WebSessionsDatabase.close_database()
