<?php
require_once('controls.php');

function get_websessions_link($url, $server_id, $group_by, $group_id=null, $hostname=null, $session_id=null)
{
	$params = array();

	if (!empty($server_id) || $server_id == 0)	{ add_url_parameter($params, 'server_id', $server_id); }
	if (!empty($group_by)) { add_url_parameter($params, 'group_by', $group_by); }
	if (!empty($group_id))
	{
		if ($group_by == GROUP_BY_DATE) { add_url_parameter($params, 'date', $group_id); }
		else if ($group_by == GROUP_BY_HOST) { add_url_parameter($params, 'domain', $group_id); }
	}
	if (!empty($hostname)) { add_url_parameter($params, 'hostname', $hostname); }
	if (!empty($session_id)) { add_url_parameter($params, 'session_id', $session_id); }

	return $url . '?' . implode('&amp;', $params);
}

function get_report_link($url, $params, $server_id, $start_date_parts=null, $end_date_parts=null)
{
	$url_params = array();
	foreach (array_keys($params) as $key) { add_url_parameter($url_params, $key, $params[$key]); }

	add_url_parameter($url_params, 'server_id', $server_id);
	if (!empty($start_date_parts[0]))
	{
		add_url_parameter($url_params, 'start_date_year', $start_date_parts[1]);
		add_url_parameter($url_params, 'start_date_month', $start_date_parts[2]);
		add_url_parameter($url_params, 'start_date_day', $start_date_parts[3]);
	}
	if (!empty($end_date_parts[0]))
	{
		add_url_parameter($url_params, 'end_date_year', $end_date_parts[1]);
		add_url_parameter($url_params, 'end_date_month', $end_date_parts[2]);
		add_url_parameter($url_params, 'end_date_day', $end_date_parts[3]);
	}
	return $url . '?' . implode('&amp;', $url_params);
}

function add_url_parameter(&$arr, $key, $val) { array_push($arr, $key . '=' . urlencode($val)); }

function get_websessions_breadcrumb($servers, $getvars, $report_name)
{
	$breadcrumb = array();

	// Server
	$group_by = !empty($getvars['group_by']) ? $getvars['group_by'] : GROUP_BY_DATE;
	$server_id = !empty($getvars['server_id']) ? $getvars['server_id'] : '0';
	$link = get_websessions_link('index.php', $server_id, $group_by);
	array_push($breadcrumb, '<a href="' . $link . '">' . $servers[$server_id]['name'] . '</a>');	

	switch ($group_by)
	{
		case GROUP_BY_HOST:
			$group_id = !empty($getvars['domain']) ? $getvars['domain'] : '';
			break;

		case GROUP_BY_DATE:
			$group_id = !empty($getvars['date']) ? $getvars['date'] : '';
			break;
	}

	// Group by date
	if (!empty($getvars['date']))
	{
		$link = get_websessions_link('sessions_by_date.php', $server_id, $group_by, $group_id);
	
		$months = array('','January','February','March','April','May','June','July','August','September','October','November','December');
		$date_parts = explode('-', $group_id);
		array_push($breadcrumb, '<a href="' . $link . '">' . $months[intval($date_parts[1])] . ' ' . $date_parts[2] . ', ' .$date_parts[0] . '</a>');
		
	}

	// Group by domain
	if (!empty($getvars['domain']))
	{
		$link = get_websessions_link('sessions_by_domain.php', $server_id, $group_by, $group_id);
		array_push($breadcrumb, '<a href="' . $link . '">' . $group_id . '</a>');
	}

	// Hostname
	if (!empty($getvars['hostname']))
	{
		$hostname = $getvars['hostname'];
		$link = get_websessions_link('sessions_by_hostname.php', $server_id, $group_by, $group_id, $hostname);
		array_push($breadcrumb, '<a href="' . $link . '">' . $hostname . '</a>');
	}

	// Session
	if (!empty($getvars['session_id']))
	{
		$session_id = $getvars['session_id'];
		$link = get_websessions_link('session.php', $server_id, $group_by, $group_id, $hostname, $session_id);
		array_push($breadcrumb, '<a href="' . $link . '">Session #' . ltrim($session_id, '0') . '</a>');
	}

	// Get start date/end date info
	$start_date_parts = get_date_control_value($getvars, 'start_date');
	$end_date_parts = get_date_control_value($getvars, 'end_date');

	// Referrer report
	if (!empty($getvars['referrer_domain']))
	{
		$url = get_report_link('referrers.php', array(), $server_id, $start_date_parts, $end_date_parts);
		array_push($breadcrumb, '<a href="' . $url . '">Referrers</a>');
	}

	// Search Term report
	if (!empty($getvars['search_term']) || !empty($getvars['search_engine']) || $getvars['search_engine'] == '0')
	{
		if (!empty($getvars['search_term'])) { $group_by = GROUP_BY_SEARCHTERMS; }
		else if (!empty($getvars['search_engine']) || $getvars['search_engine'] == '0') { $group_by = GROUP_BY_SEARCHENGINES; }

		$url = get_report_link('searchterms.php', array('group_by' => $group_by), $server_id, $start_date_parts, $end_date_parts);
		array_push($breadcrumb, '<a href="' . $url .'">Search Terms</a>');
	}

	// Report name
	if (!empty($report_name))
	{
		array_push($breadcrumb, $report_name);
	}

	// Last item shouldn't be a link
	$breadcrumb[count($breadcrumb)-1] = strip_tags($breadcrumb[count($breadcrumb)-1]);
	return implode(' &gt; ', $breadcrumb);

}

?>
